SiUnitName

Enum SiUnitName 

pub enum SiUnitName {
Show 28 variants Metre, Gram, Second, Ampere, Kelvin, Mole, Candela, Radian, Steradian, Hertz, Newton, Pascal, Joule, Watt, Coulomb, Volt, Farad, Ohm, Siemens, Weber, Tesla, Henry, DegreeCelsius, Lumen, Lux, Becquerel, Gray, Sievert,
}

Variants



Metre



Gram



Second



Ampere



Kelvin



Mole



Candela



Radian



Steradian



Hertz



Newton



Pascal



Joule



Watt



Coulomb



Volt



Farad



Ohm



Siemens



Weber



Tesla



Henry



DegreeCelsius



Lumen



Lux



Becquerel



Gray



Sievert

Implementations

Source

impl SiUnitName

pub fn parse(s: &str) -> Option<Self>

pub fn token(self) -> &'static str